#
# spec file for package caffeine
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %{suse_version} == 1315 && ! 0%{?is_opensuse}
%define __requires_exclude typelib\\(AppIndicator3\\)
%endif

Name:           caffeine
Version:        2.8.3
Release:        bp155.2.11
Summary:        Utility to inhibit screensaver and sleep modes
License:        GPL-3.0+ and LGPL-3.0+
Group:          System/GUI/GNOME
Url:            https://launchpad.net/caffeine
Source0:        https://launchpad.net/ubuntu/+archive/primary/+files/%{name}_%{version}.orig.tar.gz
# PATCH-FIX-UPSTREAM caffeine-fix-desktop-file-semicolon-trailing-character p.drouand@gmail.com -- Fix missing semicolon in Keywords entries.
Patch1:         caffeine-fix-desktop-file-semicolon-trailing-character.patch
BuildRequires:  fdupes
# For typelib() Requires
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       python3-xdg
Requires:       python3-xlib
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Caffeine is a status bar application able to temporarily prevent the
activation of both the screensaver and the "sleep" powersaving mode.

%prep
%setup -q -n %{name}
%patch1 -p1

%build
python3 setup.py build

%install
python3 setup.py install -O1 --prefix=%{_prefix} --root=%{buildroot}
%suse_update_desktop_file -G Caffeine -r -u %{buildroot}%{_datadir}/applications/caffeine.desktop Utility TrayIcon
%suse_update_desktop_file -G Caffeine -r -u %{buildroot}%{_sysconfdir}/xdg/autostart/%{name}.desktop Utility TrayIcon
%find_lang %{name}-indicator
# Remove ubuntu icons for now
rm -rf %{buildroot}%{_datadir}/icons/ubuntu-mono-dark

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}-indicator.lang
%defattr(-,root,root)
%doc COPYING COPYING.LESSER README
%{_bindir}/caffein*
%{python3_sitelib}/ewmh*
%{python3_sitelib}/__pycache__/ewmh*
%{python3_sitelib}/caffeine-%{version}-py%{py3_ver}.egg-info
%{_datadir}/caffeine-indicator
%{_datadir}/applications/caffeine*.desktop
%{_datadir}/icons/*/*/*/caffeine*
%{_datadir}/pixmaps/caffeine.*
%{_mandir}/man?/caffein*%{?ext_man}
%{_sysconfdir}/xdg/autostart/caffeine.desktop

%changelog
* Mon Jul 11 2016 dimstar@opensuse.org
- Only filter out AppIndicator dependency on SLE - all versions of
  openSUSE where caffeine builds for have libappindicator
  available.
* Sun Nov  1 2015 p.drouand@gmail.com
- Update to version 2.8.3
  + No changelog for this version
- Changes from version 2.8.2
  + Fixes some minor bugs in 2.8.
  + Fix a major bug inadvertently introduced in the short-lived
    2.8.1 (caffeine-indicator was broken).
- Changes from version 2.8
  + Restores widely-missed functionality removed in Caffeine 2.7:
    namely the ability to inhibit desktop idleness manually,
    (via the new caffeine-indicator) and the ability to inhibit
    desktop idleness for the duration of a particular command
    (via the new command 'caffeinate'). It should also work in most
    desktop environments again (Caffeine 2.7 worked in only a few).
- Replace python-devel BuildRequires with python3-devel: follow
  upstreams port to python3
- Changed dependencies:
  + python3-xdg in place of python-xdg
  + python3-xlib in place of python-xlib
- Rebase
  caffeine-fix-desktop-file-semicolon-trailing-character.patch.
* Mon Dec 29 2014 zaitor@opensuse.org
- Rebase
  caffeine-fix-desktop-file-semicolon-trailing-character.patch to
  really fix the missing trailing ;
- Drop %%lang_package macro that was still present.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 2.7.2:
  + Fix a crash when there is no active window (lp#1322291).
  + Fix Caffeine not terminating when the session ends
    (lp#1324304).
- Changes from version 2.7.1:
  + Fix a crash when a window disappears during full-screen check.
- Changes from version 2.7:
  + Remove manual control, and hence UI.
  + Allow multiple instances per user: should really be one per X
    display.
- Changes from version 2.6.2:
  + Add a build number just to persuade Launchpad to rebuild.
- Changes from version 2.6:
  + Auto-activate the screensaver when a full-screen window is
    present.
  + Remove the ability to watch processes; applications should
    inhibit idleness themselves, and many now do.
  + Remove -a and -d command-line arguments: single-instance
    nature of Caffeine means it shouldn't be used from the command
    line. xdg-screensaver should be used instead.
  + Bump to standards 3.9.5 (no change).
- Changes from version 2.5:
  + Fix right-click on icon (lp#892663).
  + Replace autostart option with an XDG autostart .desktop file.
  + Remove specific support for Quake Live.
  + Require appindicator3; remove non-appindicator support.
  + Put requirement for notify support in package, not code.
  + Remove ability to disable icon: this should be done by the
    desktop environment, not the application.
  + Remove hash-bang lines from non-executable files (lp#931875).
  + Fix race condition for notifications, patch from André Ericson
    (lp#892865).
  + Fix i18n issues (lp#941495).
  + Fix Open Build Service desktop file errors (lp#931874).
  + Add dependencies for all required libraries (lp#1093324).
  + Fix recognition of apps which mention their name in their
    arguments (lp#1249796).
  + Use freedesktop ScreenSaver DBus API instead of per-desktop
    APIs (lp#1239935).
  + Put description string on one line in setup.py to placate
    rpmbuild (lp#595889).
  + Remove non-working Flash support.
  + Remove custom logging module.
  + Remove --preferences command-line option, no longer needed.
  + Remove --time command-line option: we're not supporting timed
    disabling any more.
  + Make Ctrl+C work (lp#907517).
- Remove obsolete patches (fixed upstream):
  + caffeine-add-indicator-menu.patch
  + caffeine-fix-desktop-categories.patch
  + caffeine-fix-non-executable-script.patch
- Added
  caffeine-fix-desktop-file-semicolon-trailing-character.patch: fix
  missing semicolons in .desktop file.
- Drop glib2-devel BuildRequires: caffeine no longer install a
  gschema file.
- Remove glib2_gsettings_schema_post/postun due to above change.
- Drop and deprecate caffeine-lang subpackage: upstream does not
  provide translations anymore.
- Remove deprecated %%py_requires.
- ICONS.INFO doesn't exist anymore.
* Sun Sep 22 2013 dimstar@opensuse.org
- Add python-xdg Requires (bnc#819520).
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Tue Feb 14 2012 malcolmlewis@opensuse.org
- Add caffeine-fix-desktop-categories.patch: Fix categories string
  and missing semi-colon (lp#931874).
- Add caffeine-fix-non-executable-script.patch: Fix
  non-executable-script warnings (lp#931875).
* Mon Jan  9 2012 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Tue Dec 13 2011 malcolmlewis@opensuse.org
- Add requires exclusion for AppIndicator3.
* Mon Dec 12 2011 malcolmlewis@opensuse.org
- Spec file clean up to remove rpmlint warnings.
- Add requires python-xlib.
* Sun Dec 11 2011 malcolmlewis@opensuse.org
- Initial build.
